@@ -243,8 +243,8 @@ TABLESPACE USER_DATA;
 /
 COMMENT ON TABLE OPLIST_DEBUG IS 'Logging-Tabelle';
 /
-COMMENT ON COLUMN OPLIST_DEBUG.ERST 'Zeitpunkt des Logeintrags';
-COMMENT ON COLUMN OPLIST_DEBUG.VALUE 'Logeintrag';
+COMMENT ON COLUMN OPLIST_DEBUG.ERST IS 'Zeitpunkt des Logeintrags';
+COMMENT ON COLUMN OPLIST_DEBUG.VALUE IS 'Logeintrag';
 /
 ----------------------------------------------------------------------
 -- ERSTELLUNG SEQUENCES
@@ -312,6 +312,17 @@ CREATE TABLE OPLIST_VERSION (
 )
 TABLESPACE USER_DATA;
 /
+CREATE UNIQUE INDEX PKOPLISTVERSION ON OPLIST_VERSION
+(OPVID)
+TABLESPACE USER_INDEX;
+/
+ALTER TABLE OPLIST_VERSION ADD (
+  CONSTRAINT PKOPLISTVERSION
+ PRIMARY KEY
+ (OPVID)
+    USING INDEX 
+    TABLESPACE USER_INDEX);
+/
 COMMENT ON TABLE OPLIST_VERSION IS 'Tabelle zur Speicherung der Versionen';
 /
 COMMENT ON COLUMN OPLIST_VERSION.OPVID IS 'PK';
