@@ -94,7 +94,7 @@ Insert into OPLIST_PRODUCT
 Insert into OPLIST_PRODUCT
    (OPPID, OPPTEXT, ACTIVE)
  Values
-   (22, 'Malfunction');
+   (22, 'Malfunction', 1);
 Insert into OPLIST_PRODUCT
    (OPPID, OPPTEXT, ACTIVE)
  Values
